@@ -1,16 +1,14 @@
-
 from eth_account import Account
 
 
 class Signer:
     def __init__(self, private_key: str, chain_id: int):
-        assert(private_key is not None and chain_id is not None)
-        
+        assert private_key is not None and chain_id is not None
+
         self.private_key = private_key
         self.account = Account.from_key(private_key)
         self.chain_id = chain_id
 
-    @property
     def address(self):
         return self.account.address
 
@@ -21,4 +19,4 @@ class Signer:
         """
         Signs a message hash
         """
-        return Account._sign_hash(message_hash, self.private_key).signature.hex()
\ No newline at end of file
+        return Account._sign_hash(message_hash, self.private_key).signature.hex()
